@@ -72,7 +72,7 @@ class Pound(object):
         open(self.cfgfile, 'w').write(str(c))
         self.runscript()
         self.options.created(self.outputdir)
-        return self.options.created
+        return self.options.created()
         
     def runscript(self):
         target=os.path.join(self.buildout["buildout"]["bin-directory"],self.name)
